@@ -118,6 +118,7 @@ def create(config):
         "site = {\n"
         '    "name": "%s",\n'
         '    "url": "%s",\n'
+        '    # "prefix": "blog",\n'
         '}\n\n'
     ) % (site_name, site_url)
 
@@ -127,7 +128,7 @@ def create(config):
     if not os.path.isdir(source):
         os.makedirs(source)
 
-    output = raw_input("Where is your directory for output(deply): ")
+    output = raw_input("Where is your directory for output(deploy): ")
     output = output or 'deploy'
     code += "output = '%s'\n" % output
     code += "static_output = '%s/static'\n" % output
