@@ -8,9 +8,9 @@ Reader, read content, parse to html.
 '''
 
 import os
-import datetime
 import logging
 from liquidluck.options import settings, g
+from liquidluck.utils import to_datetime, import_object
 
 
 class BaseReader(object):
@@ -31,7 +31,7 @@ class BaseReader(object):
         self.filepath = filepath
 
     @property
-    def short_filepath(self):
+    def relative_filepath(self):
         return self.filepath[len(g.source_directory) + 1:]
 
     def start(self):
@@ -48,6 +48,16 @@ class BaseReader(object):
                     return True
         return False
 
+    def get(self, key, value=None):
+        return settings.readers_variables.get(key, value)
+
+    @property
+    def post_class(self):
+        cls = self.get('post_class', Post)
+        if isinstance(cls, str):
+            return import_object(cls)
+        return cls
+
     def render(self):
         raise NotImplementedError
 
@@ -136,14 +146,21 @@ class Post(object):
         path = os.path.split(self.filepath)[1]
         return os.path.splitext(path)[0]
 
+    @property
+    def filedir(self):
+        path = self.filepath
+        if path.startswith(g.source_directory):
+            path = path[len(g.source_directory) + 1:]
+
+        return os.path.split(path)[0]
+
     def __getattr__(self, key):
         try:
             return super(Post, self).__getattr__(key)
         except:
             pass
-        if key in self.meta:
-            return self.meta[key]
-        raise AttributeError
+        #: won't raise AttributeError
+        return self.meta.get(key)
 
 
 class Author(object):
@@ -170,23 +187,3 @@ class Author(object):
     @property
     def email(self):
         return self._d.get('email', None)
-
-
-def to_datetime(value):
-    supported_formats = [
-        '%a %b %d %H:%M:%S %Y',
-        '%Y-%m-%d %H:%M:%S',
-        '%Y-%m-%d %H:%M',
-        '%Y-%m-%dT%H:%M',
-        '%Y%m%d %H:%M:%S',
-        '%Y%m%d %H:%M',
-        '%Y-%m-%d',
-        '%Y%m%d',
-    ]
-    for format in supported_formats:
-        try:
-            return datetime.datetime.strptime(value, format)
-        except ValueError:
-            pass
-    logging.error('Unrecognized date/time: %r' % value)
-    raise ValueError('Unrecognized date/time: %r' % value)
