@@ -40,7 +40,6 @@ class BaseWriter(object):
         logging.info('%s Finished' % name)
 
     def write(self, content, destination):
-        destination = destination.lower()
         destination = destination.replace(' ', '-')
         folder = os.path.split(destination)[0]
         # on Mac OSX, `folder` == `FOLDER`
@@ -54,13 +53,13 @@ class BaseWriter(object):
         return
 
     def render(self, params, template, destination):
+        filepath = destination[len(g.output_directory) + 1:]
+        filepath = filepath.lower()
         if g.detail_logging:
-            filepath = destination[len(g.output_directory) + 1:]
             logging.info('write %s' % filepath)
         tpl = g.jinja.get_template(template)
         html = tpl.render(params)
-        self.write(html, destination)
-        #: logging
+        self.write(html, os.path.join(g.output_directory, filepath))
         return
 
     def get(self, key, value=None):
@@ -129,6 +128,8 @@ def load_jinja():
     theme = os.path.join(os.path.abspath('_themes'), settings.theme)
     if not os.path.exists(theme):
         theme = os.path.join(g.liquid_directory, '_themes', settings.theme)
+    if not os.path.exists(theme):
+        logging.error("Can't find theme: %s" % settings.theme)
 
     #: global variable
     g.theme_directory = theme
@@ -235,6 +236,7 @@ def get_post_slug(post, slug_format):
     slug = regex.sub(replace, slug_format)
     slug = slug.lstrip('/').replace('//', '/').replace(' ', '-')
     prefix = settings.site.get('prefix', '').rstrip('/')
+    slug = slug.lower()
     if prefix:
         return '%s/%s' % (prefix, slug)
     return slug
